# Changelog

<!-- <START NEW CHANGELOG ENTRY> -->

## 0.1.1

([Full Changelog](https://github.com/DerThorsten/ptjnb/compare/c00f22f60b9f39f4584be3e7ad0a93f0a8e40245...57c90516f03fa98dd82ac4fa6a627af9ebba338d))

### Merged PRs

- fix: CI [#3](https://github.com/DerThorsten/ptjnb/pull/3) ([@trungleduc](https://github.com/trungleduc), [@DerThorsten](https://github.com/DerThorsten))
- update project [#1](https://github.com/DerThorsten/ptjnb/pull/1) ([@trungleduc](https://github.com/trungleduc), [@DerThorsten](https://github.com/DerThorsten))

### Contributors to this release

The following people contributed discussions, new ideas, code and documentation contributions, and review.
See [our definition of contributors](https://github-activity.readthedocs.io/en/latest/use/#how-does-this-tool-define-contributions-in-the-reports).

([GitHub contributors page for this release](https://github.com/DerThorsten/ptjnb/graphs/contributors?from=2026-03-11&to=2026-03-16&type=c))

@DerThorsten ([activity](https://github.com/search?q=repo%3ADerThorsten%2Fptjnb+involves%3ADerThorsten+updated%3A2026-03-11..2026-03-16&type=Issues)) | @trungleduc ([activity](https://github.com/search?q=repo%3ADerThorsten%2Fptjnb+involves%3Atrungleduc+updated%3A2026-03-11..2026-03-16&type=Issues))

<!-- <END NEW CHANGELOG ENTRY> -->
